@@ -1,3 +1,15 @@
+#' Plot output from BchronDensity
+#'
+#' @param x Output from \code{\link{BchronDensity}}
+#' @param plotDates Whether to plot the individual calibrated dates
+#' @param plotRawSum Whether to plot the raw sum of the probability distributions
+#' @param plotPhase Whether to plot the phase values
+#' @param phaseProb The probability value for the phase identification
+#' @param ... Other graphical commands. See \code{\link{par}}
+#'
+#' @seealso See  \code{\link{BchronDensity}} for examples, also \code{\link{Bchronology}}, \code{\link{BchronRSL}}, and \code{\link{BchronDensityFast}} for a faster approximate version of this function
+#'
+#' @export
 plot.BchronDensityRun <-
 function(x,plotDates=TRUE,plotRawSum=FALSE,plotPhase=TRUE,phaseProb=0.95,...) {
 
@@ -58,7 +70,7 @@ function(x,plotDates=TRUE,plotRawSum=FALSE,plotPhase=TRUE,phaseProb=0.95,...) {
   if(plotPhase) {
     phases = hdr(x, prob = phaseProb)
     for(i in 1:length(phases)) {
-      lines(c(phases[[i]][1],phases[[i]][2]), c(0,0), lwd = 3)
+      graphics::lines(c(phases[[i]][1],phases[[i]][2]), c(0,0), lwd = 3)
     }
   }
 
