@@ -1,3 +1,17 @@
+#' Summarise a Bchronology object
+#'
+#' Summarise a \code{\link{Bchronology}} object
+#'
+#' @param object Output from a run of \code{\link{Bchronology}}
+#' @param type Type of output required. The default (quantiles) gives the quantiles of the ages for each position in \code{predictPositions} from \code{\link{Bchronology}}. The other options provide outlier probabilities, convergence diagnostics, accumulation rates and sedimentation rate
+#' @param probs Probabilities (between 0 and 1) at which to summarise the predicted chronologies
+#' @param useExisting Whether to use the predicted chronologies/positions to calculate the sedimentation rate (if TRUE - default) or to re-create them based on a unit-scaled position grid (if FALSE). The latter will be a little bit slower but will provide better sedimentation rate estimates if the original positions are not on a unit scale (e.g. each cm)
+#' @param ... Other arguments (not currently supported)
+#' @param digits Number of digits to report values
+#' @export
+#' 
+#' @seealso \code{\link{BchronCalibrate}}, \code{\link{Bchronology}} \code{\link{BchronRSL}}, \code{\link{BchronDensity}}, \code{\link{BchronDensityFast}}
+#'
 summary.BchronologyRun <-
 function(object,type=c('quantiles','outliers','convergence','sed_rate','acc_rate'),probs=c(0.025,0.1,0.5,0.9,0.975), useExisting = TRUE, ..., digits = max(3, getOption("digits")-3)) {
   type = match.arg(type)
@@ -42,7 +56,7 @@ function(object,type=c('quantiles','outliers','convergence','sed_rate','acc_rate
         chrons = predict.BchronologyRun(object, newPositions = position_grid)
     }
       sed_rate = apply(chrons, 1, 'diff')
-      sed_rate_ci = cbind(position_grid[-1], t(apply(sed_rate, 1, 'quantile', probs = probs)))
+      sed_rate_ci = cbind(position_grid[-1], t(apply(sed_rate, 1, stats::quantile, probs = probs)))
       colnames(sed_rate_ci)[1] = 'position_grid'
       print(round(sed_rate_ci, digits=digits),row.names=FALSE)
       invisible(sed_rate_ci)
@@ -50,11 +64,11 @@ function(object,type=c('quantiles','outliers','convergence','sed_rate','acc_rate
     acc_rate = {
       cat('Accumulation rate (position units per time unit): \n')
       chrons = object$thetaPredict
-      age_grid = seq(quantile(chrons, 0.05), quantile(chrons, 0.95), by = 1)
+      age_grid = seq(stats::quantile(chrons, 0.05), stats::quantile(chrons, 0.95), by = 1)
       my_fun = function(x) stats::approx(x, y = object$predictPositions, xout = age_grid, rule = 2)$y
       position_interp = t(apply(chrons, 1, my_fun))
       acc_rate = apply(position_interp, 1, 'diff')
-      acc_rate_ci = cbind(age_grid[-1], t(apply(acc_rate, 1, 'quantile', probs = probs)))
+      acc_rate_ci = cbind(age_grid[-1], t(apply(acc_rate, 1, stats::quantile, probs = probs)))
       colnames(acc_rate_ci)[1] = 'age_grid'
       print(round(acc_rate_ci, digits=digits),row.names=FALSE)
       invisible(acc_rate_ci)
